@@ -4,6 +4,7 @@ Manages the execution of all pipeline stages in sequence
 """
 
 from typing import Dict, Any, List, Optional
+import copy
 import time
 from datetime import datetime
 import uuid
@@ -558,9 +559,44 @@ class FuseSellPipeline:
         
         elif stage_name == 'initial_outreach':
             # Combine data from previous stages
+            customer_data = {}
             if 'data_preparation' in stage_results:
                 prep_data = stage_results['data_preparation'].get('data', {})
-                base_input['customer_data'] = prep_data
+                if isinstance(prep_data, dict):
+                    customer_data = copy.deepcopy(prep_data)
+            else:
+                existing_customer_data = base_input.get('customer_data', {})
+                if isinstance(existing_customer_data, dict):
+                    customer_data = copy.deepcopy(existing_customer_data)
+            
+            if not isinstance(customer_data, dict):
+                customer_data = {}
+            
+            primary_contact = dict(customer_data.get('primaryContact') or {})
+            input_email = (
+                base_input.get('recipient_address')
+                or base_input.get('customer_email')
+                or primary_contact.get('email')
+                or customer_data.get('contact_email')
+            )
+            if input_email:
+                primary_contact['email'] = input_email
+                customer_data['contact_email'] = input_email
+            
+            input_name = (
+                base_input.get('recipient_name')
+                or base_input.get('customer_name')
+                or primary_contact.get('name')
+                or customer_data.get('contact_name')
+            )
+            if input_name:
+                primary_contact['name'] = input_name
+                customer_data['contact_name'] = input_name
+            
+            if primary_contact:
+                customer_data['primaryContact'] = primary_contact
+            
+            base_input['customer_data'] = customer_data
             
             if 'lead_scoring' in stage_results:
                 scoring_data = stage_results['lead_scoring'].get('data', {})
