@@ -3,13 +3,14 @@ FuseSell Utilities - Common utilities and helper functions
 """
 
 from .data_manager import LocalDataManager
-from .llm_client import LLMClient
+from .llm_client import LLMClient, normalize_llm_base_url
 from .validators import InputValidator
 from .logger import setup_logging
 
 __all__ = [
     'LocalDataManager',
-    'LLMClient', 
+    'LLMClient',
+    'normalize_llm_base_url',
     'InputValidator',
     'setup_logging'
-]
\ No newline at end of file
+]
