@@ -183,17 +183,17 @@ class EventScheduler:
             ISO 8601 formatted string.
         """
         if isinstance(value, datetime):
-            return value.isoformat()
+            return value.replace(second=0, microsecond=0).isoformat()
         if value is None:
-            return datetime.utcnow().isoformat()
+            return datetime.utcnow().replace(second=0, microsecond=0).isoformat()
 
         value_str = str(value).strip()
         if not value_str:
-            return datetime.utcnow().isoformat()
+            return datetime.utcnow().replace(second=0, microsecond=0).isoformat()
 
         try:
             parsed = datetime.fromisoformat(value_str)
-            return parsed.isoformat()
+            return parsed.replace(second=0, microsecond=0).isoformat()
         except ValueError:
             return value_str
 
@@ -283,7 +283,7 @@ class EventScheduler:
         customextra.setdefault('recipient_name', recipient_name)
         customextra.setdefault('draft_id', draft_id)
         customextra.setdefault('customer_timezone', customer_timezone)
-        customextra.setdefault('scheduled_time_utc', send_time.isoformat())
+        customextra.setdefault('scheduled_time_utc', self._format_datetime(send_time))
 
         if team_id and 'team_id' not in customextra:
             customextra['team_id'] = team_id
